==> civicrm_5.11.0+dfsg.orig.tar.xz: civicrm/api/v3/Grant.php <==
<?php
/*
 +--------------------------------------------------------------------+
 | CiviCRM version 5                                                  |
 +--------------------------------------------------------------------+
 | Copyright CiviCRM LLC (c) 2004-2019                                |
 +--------------------------------------------------------------------+
 | This file is a part of CiviCRM.                                    |
 |                                                                    |
 | CiviCRM is free software; you can copy, modify, and distribute it  |
 | under the terms of the GNU Affero General Public License           |
 | Version 3, 19 November 2007 and the CiviCRM Licensing Exception.   |
 |                                                                    |
 | CiviCRM is distributed in the hope that it will be useful, but     |
 | WITHOUT ANY WARRANTY; without even the implied warranty of         |
 | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.               |
 | See the GNU Affero General Public License for more details.        |
 |                                                                    |
 | You should have received a copy of the GNU Affero General Public   |
 | License and the CiviCRM Licensing Exception along                  |
 | with this program; if not, contact CiviCRM LLC                     |
 | at info[AT]civicrm[DOT]org. If you have questions about the        |
 | GNU Affero General Public License or the licensing of CiviCRM,     |
 | see the CiviCRM license FAQ at http://civicrm.org/licensing        |
 +--------------------------------------------------------------------+
 */

/**
 * This api exposes CiviCRM Grant records.
 *
 * @note Grant component must be enabled.
 *
 * @package CiviCRM_APIv3
 */

/**
 * Create/update Grant.
 *
 * @param array $params
 *   Array per getfields metadata.
 *
 * @return array
 */
function civicrm_api3_grant_create($params) {
  return _civicrm_api3_basic_create(_civicrm_api3_get_BAO(__FUNCTION__), $params, 'Grant');
}

/**
 * Adjust Metadata for Create action.
 *
 * The metadata is used for setting defaults, documentation & validation.
 *
 * @param array $params
 *   Array of parameters determined by getfields.
 */
function _civicrm_api3_grant_create_spec(&$params) {
  $params['contact_id']['api.required'] = 1;
  $params['grant_type_id']['api.required'] = 1;
  $params['status_id']['api.required'] = 1;
  $params['amount_total']['api.required'] = 1;
  $params['status_id']['api.aliases'] = array('grant_status');
}

/**
 * Returns array of grants matching a set of one or more properties.
 *
 * @param array $params
 *   Array per getfields metadata.
 *
 * @return array
 *   Array of matching grants
 */
function civicrm_api3_grant_get($params) {
  return _civicrm_api3_basic_get(_civicrm_api3_get_BAO(__FUNCTION__), $params, TRUE, 'Grant');
}

/**
 * This method is used to delete an existing Grant.
 *
 * @param array $params
 *   Id of the Grant to be deleted is required.
 *
 * @return array
 *   API Result Array
 */
function civicrm_api3_grant_delete($params) {
  return _civicrm_api3_basic_delete(_civicrm_api3_get_BAO(__FUNCTION__), $params);
}

==> civicrm_5.18.1+dfsg.orig.tar.xz: civicrm/api/v3/Grant.php <==
<?php
/*
 +--------------------------------------------------------------------+
 | CiviCRM version 5                                                  |
 +--------------------------------------------------------------------+
 | Copyright CiviCRM LLC (c) 2004-2019                                |
 +--------------------------------------------------------------------+
 | This file is a part of CiviCRM.                                    |
 |                                                                    |
 | CiviCRM is free software; you can copy, modify, and distribute it  |
 | under the terms of the GNU Affero General Public License           |
 | Version 3, 19 November 2007 and the CiviCRM Licensing Exception.   |
 |                                                                    |
 | CiviCRM is distributed in the hope that it will be useful, but     |
 | WITHOUT ANY WARRANTY; without even the implied warranty of         |
 | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.               |
 | See the GNU Affero General Public License for more details.        |
 |                                                                    |
 | You should have received a copy of the GNU Affero General Public   |
 | License and the CiviCRM Licensing Exception along                  |
 | with this program; if not, contact CiviCRM LLC                     |
 | at info[AT]civicrm[DOT]org. If you have questions about the        |
 | GNU Affero General Public License or the licensing of CiviCRM,     |
 | see the CiviCRM license FAQ at http://civicrm.org/licensing        |
 +--------------------------------------------------------------------+
 */

/**
 * This api exposes CiviCRM Grant records.
 *
 * @note Grant component must be enabled.
 *
 * @package CiviCRM_APIv3
 */

/**
 * Create/update Grant.
 *
 * @param array $params
 *   Array per getfields metadata.
 *
 * @return array
 */
function civicrm_api3_grant_create($params) {
  return _civicrm_api3_basic_create(_civicrm_api3_get_BAO(__FUNCTION__), $params, 'Grant');
}

/**
 * Adjust Metadata for Create action.
 *
 * The metadata is used for setting defaults, documentation & validation.
 *
 * @param array $params
 *   Array of parameters determined by getfields.
 */
function _civicrm_api3_grant_create_spec(&$params) {
  $params['contact_id']['api.required'] = 1;
  $params['grant_type_id']['api.required'] = 1;
  $params['status_id']['api.required'] = 1;
  $params['amount_total']['api.required'] = 1;
  $params['status_id']['api.aliases'] = ['grant_status'];
}

/**
 * Returns array of grants matching a set of one or more properties.
 *
 * @param array $params
 *   Array per getfields metadata.
 *
 * @return array
 *   Array of matching grants
 */
function civicrm_api3_grant_get($params) {
  return _civicrm_api3_basic_get(_civicrm_api3_get_BAO(__FUNCTION__), $params, TRUE, 'Grant');
}

/**
 * This method is used to delete an existing Grant.
 *
 * @param array $params
 *   Id of the Grant to be deleted is required.
 *
 * @return array
 *   API Result Array
 */
function civicrm_api3_grant_delete($params) {
  return _civicrm_api3_basic_delete(_civicrm_api3_get_BAO(__FUNCTION__), $params);
}
